package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.DisasterRecoveryServicesMapper;
import com.zyc.system.domain.DisasterRecoveryServices;
import com.zyc.system.service.IDisasterRecoveryServicesService;

/**
 * 灾备服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class DisasterRecoveryServicesServiceImpl implements IDisasterRecoveryServicesService 
{
    @Autowired
    private DisasterRecoveryServicesMapper disasterRecoveryServicesMapper;

    /**
     * 查询灾备服务
     * 
     * @param id 灾备服务主键
     * @return 灾备服务
     */
    @Override
    public DisasterRecoveryServices selectDisasterRecoveryServicesById(Integer id)
    {
        return disasterRecoveryServicesMapper.selectDisasterRecoveryServicesById(id);
    }

    /**
     * 查询灾备服务列表
     * 
     * @param disasterRecoveryServices 灾备服务
     * @return 灾备服务
     */
    @Override
    public List<DisasterRecoveryServices> selectDisasterRecoveryServicesList(DisasterRecoveryServices disasterRecoveryServices)
    {
        return disasterRecoveryServicesMapper.selectDisasterRecoveryServicesList(disasterRecoveryServices);
    }

    /**
     * 新增灾备服务
     * 
     * @param disasterRecoveryServices 灾备服务
     * @return 结果
     */
    @Override
    public int insertDisasterRecoveryServices(DisasterRecoveryServices disasterRecoveryServices)
    {
        return disasterRecoveryServicesMapper.insertDisasterRecoveryServices(disasterRecoveryServices);
    }

    /**
     * 修改灾备服务
     * 
     * @param disasterRecoveryServices 灾备服务
     * @return 结果
     */
    @Override
    public int updateDisasterRecoveryServices(DisasterRecoveryServices disasterRecoveryServices)
    {
        return disasterRecoveryServicesMapper.updateDisasterRecoveryServices(disasterRecoveryServices);
    }

    /**
     * 批量删除灾备服务
     * 
     * @param ids 需要删除的灾备服务主键
     * @return 结果
     */
    @Override
    public int deleteDisasterRecoveryServicesByIds(Integer[] ids)
    {
        return disasterRecoveryServicesMapper.deleteDisasterRecoveryServicesByIds(ids);
    }

    /**
     * 删除灾备服务信息
     * 
     * @param id 灾备服务主键
     * @return 结果
     */
    @Override
    public int deleteDisasterRecoveryServicesById(Integer id)
    {
        return disasterRecoveryServicesMapper.deleteDisasterRecoveryServicesById(id);
    }
}
